@@ -32,10 +32,6 @@ public:
     void save() override;
     void defaults() override;
 
-#if QT_VERSION_MAJOR < 6
-    void setNeedsSave(bool needs) {emit changed(needs);}
-#endif
-
 private Q_SLOTS:
     void slotChanged();
     void displayEmpytStartPageWarningIfNeeded();
