@@ -48,10 +48,6 @@ public:
      */
     ~UserAgent();
 
-#if QT_VERSION_MAJOR < 6
-    void setNeedsSave(bool needs) {emit changed(needs);}
-#endif
-
 public slots:
 
     /**
